Documentation
¶
Index ¶
Constants ¶
const ( UTF8 = Charset("UTF-8") GB18030 = Charset("GB18030") )
Variables ¶
This section is empty.
Functions ¶
func ConvertByte2String ¶
func RunCommand ¶
func RunCommandWithErr ¶
func RunWithWait ¶
Types ¶
type Shell ¶
type Shell struct {
Config *Config // 配置对象
}
func NewWithConfig ¶
func (*Shell) RunWithError ¶
RunWithError 运行命令并返回结果和错误
Directories
¶
| Path | Synopsis |
|---|---|
|
Package encoding defines an interface for character encodings, such as Shift JIS and Windows 1252, that can convert to and from UTF-8.
|
Package encoding defines an interface for character encodings, such as Shift JIS and Windows 1252, that can convert to and from UTF-8. |
|
charmap
Package charmap provides simple character encodings such as IBM Code Page 437 and Windows 1252.
|
Package charmap provides simple character encodings such as IBM Code Page 437 and Windows 1252. |
|
htmlindex
Package htmlindex maps character set encoding names to Encodings as recommended by the W3C for use in HTML 5.
|
Package htmlindex maps character set encoding names to Encodings as recommended by the W3C for use in HTML 5. |
|
ianaindex
Package ianaindex maps names to Encodings as specified by the IANA registry.
|
Package ianaindex maps names to Encodings as specified by the IANA registry. |
|
internal
Package internal contains code that is shared among encoding implementations.
|
Package internal contains code that is shared among encoding implementations. |
|
internal/identifier
Package identifier defines the contract between implementations of Encoding and Index by defining identifiers that uniquely identify standardized coded character sets (CCS) and character encoding schemes (CES), which we will together refer to as encodings, for which Encoding implementations provide converters to and from UTF-8.
|
Package identifier defines the contract between implementations of Encoding and Index by defining identifiers that uniquely identify standardized coded character sets (CCS) and character encoding schemes (CES), which we will together refer to as encodings, for which Encoding implementations provide converters to and from UTF-8. |
|
simplifiedchinese
Package simplifiedchinese provides Simplified Chinese encodings such as GBK.
|
Package simplifiedchinese provides Simplified Chinese encodings such as GBK. |
|
traditionalchinese
Package traditionalchinese provides Traditional Chinese encodings such as Big5.
|
Package traditionalchinese provides Traditional Chinese encodings such as Big5. |
|
unicode
Package unicode provides Unicode encodings such as UTF-16.
|
Package unicode provides Unicode encodings such as UTF-16. |
|
unicode/utf32
Package utf32 provides the UTF-32 Unicode encoding.
|
Package utf32 provides the UTF-32 Unicode encoding. |
|
examples
|
|
|
hello
command
|
Click to show internal directories.
Click to hide internal directories.